@@ -8,16 +8,15 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_iam._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import cdk8s._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@opencdk8s/cdk8s-cluster-autoscaler-aws",
-    "0.0.5",
+    "0.1.0",
     __name__[0:-6],
-    "cdk8s-cluster-autoscaler-aws@0.0.5.jsii.tgz",
+    "cdk8s-cluster-autoscaler-aws@0.1.0.jsii.tgz",
 )
 
 __all__ = [
